JoltWatcherHookCreator class final
Watcher hook factory methods.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call<
T> (T sources(), WatcherFn< T> fn, {List<Object?> ? keys, JoltDebugOption? debug, bool immediately = false, WhenFn<T> ? when}) → Watcher -
Creates a
Watcherover values returned bysources. -
immediately<
T> (T sources(), WatcherFn< T> fn, {List<Object?> ? keys, JoltDebugOption? debug, WhenFn<T> ? when}) → Watcher<T> -
Creates a
Watcherthat also runsfnfor the initial source values. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
once<
T> (T sources(), WatcherFn< T> fn, {List<Object?> ? keys, JoltDebugOption? debug, WhenFn<T> ? when}) → Watcher<T> -
Creates a
Watcherthat disposes itself after the first callback. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited