JoltWidgetHook<T extends Widget> class
A Hook that rebuilds a widget when reactive dependencies change.
Constructors
-
JoltWidgetHook(T builder(), {List<
Object?> ? keys, JoltDebugOption? debug}) -
Creates a hook that tracks dependencies accessed by
builder.const
Properties
- builder → T Function()
-
Builds the widget for the current hook slot.
final
- debug → JoltDebugOption?
-
Optional debug options for the internal
PostFrameEffect.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
keys
→ List<
Object?> ? -
A list of objects that specify if a
HookStateshould be reused or a new one should be created.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createState(
) → JoltWidgetHookState< T> -
Creates the mutable state for this
Hooklinked to its widget creator. -
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited